# Chapter 12: Machine Learning in Quantitative Investing

This chapter is currently maintained in Chinese first.

- Chinese chapter: [第 12 章：机器学习在量化中的应用 (Machine Learning)](../../zh/textbook/12_ml.md)
- Textbook home: [Chinese textbook index](../../zh/textbook/index.md)
- Practice links:
  - Primary example: [examples/textbook/ch12_ml.py](https://github.com/akfamily/akquant/blob/main/examples/textbook/ch12_ml.py)
  - Extended example: [examples/10_ml_walk_forward.py](https://github.com/akfamily/akquant/blob/main/examples/10_ml_walk_forward.py)
  - Guide: [Machine Learning Guide](../advanced/ml.md)
